@@ -79,6 +79,12 @@ def create_project_configuration(filename):
 def get_project_root():
     """Get the project root folder as a string."""
     cfg = get_project_configuration()
+    # At this point it can be sure that the configuration file exists
+    # Now make sure the project structure exists
+    for dirname in ["raw-datasets", "preprocessed", "feature-files", "models"]:
+        directory = os.path.join(cfg['root'], "raw-datasets/info.yml")
+        if not os.path.exists(directory):
+            os.makedirs(directory)
     return cfg['root']
 
 
